==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/containerstorage/kotlin/inputs/AzureDiskArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerstorage.kotlin.inputs

import com.pulumi.azurenative.containerstorage.inputs.AzureDiskArgs.builder
import com.pulumi.azurenative.containerstorage.kotlin.enums.AzureDiskSkuName
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Azure Disk Pool Properties
 * @property disks Only required if individual disk selection is desired. Path to disk, e.g. <nodename>:/dev/sda or WWN. Supports specifying multiple disks (same syntax as tags).
 * @property encryption Encryption specifies the encryption configuration for the Azure Disk pool
 * @property skuName Sku name
 */
public data class AzureDiskArgs(
    public val disks: Output<List<DiskArgs>>? = null,
    public val encryption: Output<EncryptionArgs>? = null,
    public val skuName: Output<Either<String, AzureDiskSkuName>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.containerstorage.inputs.AzureDiskArgs> {
    override fun toJava(): com.pulumi.azurenative.containerstorage.inputs.AzureDiskArgs =
        com.pulumi.azurenative.containerstorage.inputs.AzureDiskArgs.builder()
            .disks(disks?.applyValue({ args0 -> args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) }) }))
            .encryption(encryption?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .skuName(
                skuName?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [AzureDiskArgs].
 */
@PulumiTagMarker
public class AzureDiskArgsBuilder internal constructor() {
    private var disks: Output<List<DiskArgs>>? = null

    private var encryption: Output<EncryptionArgs>? = null

    private var skuName: Output<Either<String, AzureDiskSkuName>>? = null

    /**
     * @param value Only required if individual disk selection is desired. Path to disk, e.g. <nodename>:/dev/sda or WWN. Supports specifying multiple disks (same syntax as tags).
     */
    @JvmName("daawoaaqsxjnpwwi")
    public suspend fun disks(`value`: Output<List<DiskArgs>>) {
        this.disks = value
    }

    @JvmName("hdyusmmhmmpynlsn")
    public suspend fun disks(vararg values: Output<DiskArgs>) {
        this.disks = Output.all(values.asList())
    }

    /**
     * @param values Only required if individual disk selection is desired. Path to disk, e.g. <nodename>:/dev/sda or WWN. Supports specifying multiple disks (same syntax as tags).
     */
    @JvmName("muirnbovdybnphqh")
    public suspend fun disks(values: List<Output<DiskArgs>>) {
        this.disks = Output.all(values)
    }

    /**
     * @param value Encryption specifies the encryption configuration for the Azure Disk pool
     */
    @JvmName("vfqnrgxuhbitgydh")
    public suspend fun encryption(`value`: Output<EncryptionArgs>) {
        this.encryption = value
    }

    /**
     * @param value Sku name
     */
    @JvmName("iwcphhnkjfderrnq")
    public suspend fun skuName(`value`: Output<Either<String, AzureDiskSkuName>>) {
        this.skuName = value
    }

    /**
     * @param value Only required if individual disk selection is desired. Path to disk, e.g. <nodename>:/dev/sda or WWN. Supports specifying multiple disks (same syntax as tags).
     */
    @JvmName("nljjqyxnajghaafw")
    public suspend fun disks(`value`: List<DiskArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.disks = mapped
    }

    /**
     * @param argument Only required if individual disk selection is desired. Path to disk, e.g. <nodename>:/dev/sda or WWN. Supports specifying multiple disks (same syntax as tags).
     */
    @JvmName("skktqaanxjoqjfkp")
    public suspend fun disks(argument: List<suspend DiskArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { DiskArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.disks = mapped
    }

    /**
     * @param argument Only required if individual disk selection is desired. Path to disk, e.g. <nodename>:/dev/sda or WWN. Supports specifying multiple disks (same syntax as tags).
     */
    @JvmName("fdlcjcgggywwjeex")
    public suspend fun disks(vararg argument: suspend DiskArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { DiskArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.disks = mapped
    }

    /**
     * @param argument Only required if individual disk selection is desired. Path to disk, e.g. <nodename>:/dev/sda or WWN. Supports specifying multiple disks (same syntax as tags).
     */
    @JvmName("cjkmvxeoivnqyhri")
    public suspend fun disks(argument: suspend DiskArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(DiskArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.disks = mapped
    }

    /**
     * @param values Only required if individual disk selection is desired. Path to disk, e.g. <nodename>:/dev/sda or WWN. Supports specifying multiple disks (same syntax as tags).
     */
    @JvmName("nrwxvryglddtvjia")
    public suspend fun disks(vararg values: DiskArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.disks = mapped
    }

    /**
     * @param value Encryption specifies the encryption configuration for the Azure Disk pool
     */
    @JvmName("wwixdlcewenpnkqf")
    public suspend fun encryption(`value`: EncryptionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.encryption = mapped
    }

    /**
     * @param argument Encryption specifies the encryption configuration for the Azure Disk pool
     */
    @JvmName("oevrxbkcgipijcld")
    public suspend fun encryption(argument: suspend EncryptionArgsBuilder.() -> Unit) {
        val toBeMapped = EncryptionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.encryption = mapped
    }

    /**
     * @param value Sku name
     */
    @JvmName("takwyigyhkwoxolh")
    public suspend fun skuName(`value`: Either<String, AzureDiskSkuName>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.skuName = mapped
    }

    /**
     * @param value Sku name
     */
    @JvmName("yogtbatsutdskdji")
    public fun skuName(`value`: String) {
        val toBeMapped = Either.ofLeft<String, AzureDiskSkuName>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.skuName = mapped
    }

    /**
     * @param value Sku name
     */
    @JvmName("etfuocqiklrynhuk")
    public fun skuName(`value`: AzureDiskSkuName) {
        val toBeMapped = Either.ofRight<String, AzureDiskSkuName>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.skuName = mapped
    }

    internal fun build(): AzureDiskArgs = AzureDiskArgs(
        disks = disks,
        encryption = encryption,
        skuName = skuName,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/containerstorage/kotlin/inputs/AzureDiskArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerstorage.kotlin.inputs

import com.pulumi.azurenative.containerstorage.inputs.AzureDiskArgs.builder
import com.pulumi.azurenative.containerstorage.kotlin.enums.AzureDiskSkuName
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Azure Disk Pool Properties
 * @property disks Only required if individual disk selection is desired. Path to disk, e.g. <nodename>:/dev/sda or WWN. Supports specifying multiple disks (same syntax as tags).
 * @property encryption Encryption specifies the encryption configuration for the Azure Disk pool
 * @property skuName Sku name
 */
public data class AzureDiskArgs(
    public val disks: Output<List<DiskArgs>>? = null,
    public val encryption: Output<EncryptionArgs>? = null,
    public val skuName: Output<Either<String, AzureDiskSkuName>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.containerstorage.inputs.AzureDiskArgs> {
    override fun toJava(): com.pulumi.azurenative.containerstorage.inputs.AzureDiskArgs =
        com.pulumi.azurenative.containerstorage.inputs.AzureDiskArgs.builder()
            .disks(disks?.applyValue({ args0 -> args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) }) }))
            .encryption(encryption?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .skuName(
                skuName?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [AzureDiskArgs].
 */
@PulumiTagMarker
public class AzureDiskArgsBuilder internal constructor() {
    private var disks: Output<List<DiskArgs>>? = null

    private var encryption: Output<EncryptionArgs>? = null

    private var skuName: Output<Either<String, AzureDiskSkuName>>? = null

    /**
     * @param value Only required if individual disk selection is desired. Path to disk, e.g. <nodename>:/dev/sda or WWN. Supports specifying multiple disks (same syntax as tags).
     */
    @JvmName("relcnqdwsxeawccv")
    public suspend fun disks(`value`: Output<List<DiskArgs>>) {
        this.disks = value
    }

    @JvmName("tfwrghhewbchpwav")
    public suspend fun disks(vararg values: Output<DiskArgs>) {
        this.disks = Output.all(values.asList())
    }

    /**
     * @param values Only required if individual disk selection is desired. Path to disk, e.g. <nodename>:/dev/sda or WWN. Supports specifying multiple disks (same syntax as tags).
     */
    @JvmName("ilfiwpyldxybyire")
    public suspend fun disks(values: List<Output<DiskArgs>>) {
        this.disks = Output.all(values)
    }

    /**
     * @param value Encryption specifies the encryption configuration for the Azure Disk pool
     */
    @JvmName("vvkjjejhnpkpgyvm")
    public suspend fun encryption(`value`: Output<EncryptionArgs>) {
        this.encryption = value
    }

    /**
     * @param value Sku name
     */
    @JvmName("mcycotoejtmxapqt")
    public suspend fun skuName(`value`: Output<Either<String, AzureDiskSkuName>>) {
        this.skuName = value
    }

    /**
     * @param value Only required if individual disk selection is desired. Path to disk, e.g. <nodename>:/dev/sda or WWN. Supports specifying multiple disks (same syntax as tags).
     */
    @JvmName("uselbktvnofnvfsx")
    public suspend fun disks(`value`: List<DiskArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.disks = mapped
    }

    /**
     * @param argument Only required if individual disk selection is desired. Path to disk, e.g. <nodename>:/dev/sda or WWN. Supports specifying multiple disks (same syntax as tags).
     */
    @JvmName("kbgbgjqnlbfljedg")
    public suspend fun disks(argument: List<suspend DiskArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { DiskArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.disks = mapped
    }

    /**
     * @param argument Only required if individual disk selection is desired. Path to disk, e.g. <nodename>:/dev/sda or WWN. Supports specifying multiple disks (same syntax as tags).
     */
    @JvmName("dlfuaefeieattntk")
    public suspend fun disks(vararg argument: suspend DiskArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { DiskArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.disks = mapped
    }

    /**
     * @param argument Only required if individual disk selection is desired. Path to disk, e.g. <nodename>:/dev/sda or WWN. Supports specifying multiple disks (same syntax as tags).
     */
    @JvmName("tneeohcbaaswlujf")
    public suspend fun disks(argument: suspend DiskArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(DiskArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.disks = mapped
    }

    /**
     * @param values Only required if individual disk selection is desired. Path to disk, e.g. <nodename>:/dev/sda or WWN. Supports specifying multiple disks (same syntax as tags).
     */
    @JvmName("tuvlfmnioosjpjgh")
    public suspend fun disks(vararg values: DiskArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.disks = mapped
    }

    /**
     * @param value Encryption specifies the encryption configuration for the Azure Disk pool
     */
    @JvmName("ttuyxwexyvvfoout")
    public suspend fun encryption(`value`: EncryptionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.encryption = mapped
    }

    /**
     * @param argument Encryption specifies the encryption configuration for the Azure Disk pool
     */
    @JvmName("yhfxflqjmllbndcc")
    public suspend fun encryption(argument: suspend EncryptionArgsBuilder.() -> Unit) {
        val toBeMapped = EncryptionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.encryption = mapped
    }

    /**
     * @param value Sku name
     */
    @JvmName("tcgfkbklivgwqmku")
    public suspend fun skuName(`value`: Either<String, AzureDiskSkuName>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.skuName = mapped
    }

    /**
     * @param value Sku name
     */
    @JvmName("qjgicihslbidbmxj")
    public fun skuName(`value`: String) {
        val toBeMapped = Either.ofLeft<String, AzureDiskSkuName>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.skuName = mapped
    }

    /**
     * @param value Sku name
     */
    @JvmName("ehrlhjutposnfuhs")
    public fun skuName(`value`: AzureDiskSkuName) {
        val toBeMapped = Either.ofRight<String, AzureDiskSkuName>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.skuName = mapped
    }

    internal fun build(): AzureDiskArgs = AzureDiskArgs(
        disks = disks,
        encryption = encryption,
        skuName = skuName,
    )
}
